%*************************************************************************%
%  Program Title: 1-Dimensional Transient Diesel Jet Model                %
%  Created By: Kyle Kattke                                                %
%  Created On: 6/4/07 - 8/23/07
%  Modified by: MPM, LMP 6/11
%                                                                         %
%  Function: Program is designed to model the injection of fuel from a    %
%            fuel injector into a non-combusting, still environment.  It  %
%            predicts velocity and equivalence ratio within the jet,      %
%            as well as penetration with time and entrainment rate        %
%                                                                         %
%  Domain: The entire spray domain is discretized into small CVs.  They   %
%          are initialized to equal widths.                               %
%                                                                         %
%  Method: First, the mass and momentum in the CVs are calculated from    %
%          the fluxes for the previous time step.  The new mean           %
%          velocities are calculated, from which the flows in the CVs at  %
%          the current time step are calculated.                          %
%                                                                         %
%          Each given time step is calculated based on a set maximum      %
%          Courant number.                                                %
%                      !                                                  %
% Comments: User inputed values are all listed in top portion of code.    %
%           There are many toggles to turn various features on or off.    %                                                          %
%                                                                         %
%           Many equations and comparisons were made using methods and    % 
%           equations listed in the paper 'Effects of Gas Density and     %
%           Vaporization on Penetration and Dispersion of Diesel Sprays'  %
%           by Naber and Siebers.                                         %
%                                                                         %
%  Children Functions: (1) - Contour_Plotter.m                            %                        %
%							  (2) - InjVel.m												  %
%							  (3) - LLFA.m													  %
%*************************************************************************%
tic %timer

%--------------------- Default User Inputs -------------------------------
% Some or all of these values may be overwritten using the variable
% 'Run_Parameters', which contains a list of assignment commands, executed
% after all of the default inputs are set (see below)
rho_a = 22.3;          % [kg/m^3] Ambient density 
T_a = 900;             % [K] ambient temperature (for liquid length calc only)
rho_f = 767;           % [kg/m^3] Fuel density (n-heptane)
BT = 0.5;              % [-] F/A ratio by mass for complete vaporization of liquid
stoich_air = 15.306;   % [-] stoichiometric A/F ratio in air for the fuel used
fN2 = 0.0;             % [-] volume fraction of added N2 in intake air
Diameter = 0.128e-3;    % [meters] Injector orifice diameter
Ca = 1.0;				  % [-] area contraction coefficient
Cv = 1.0;              % [-] Velocity coefficient
theta = 15;            % [degrees] Spray spreading full-angle
a_Siebers = 0.683;     % [-] spreading angle correction factor for Siebers
                       % 0.683 gives approx same penetration with uniform velocity profile
							  % as Abramovich's parabolic velocity profile (real jet)
total_length = 0.10;   % [meters] Domain size
dx = .05e-3;            % [meters] CV widths
Courant = .2;          % [-] Courant number
velocity_profile = 1;  % [-] set to 0 for uniform velocity and 1 for Abramovich (real jet)
adjust_theta = 1;      % [-] flag to alter theta uniform velocity profile
Run_Time = 4.0E-3;     % [s] Total run time
dtmax = 1E-6;          % [s] upper time-step limit (for use with very low velocities)

InjType = 'Steady';    % Injection function type
InjParams = [420;1];   % injection function parameters 1st row: velocity [m/s], 2nd row: time [s]

M_threshold = 0.05;    % Threshold for measuring penetration by Momentum flux (vapor head)
phi_threshold = 0;     % Penetration threshold by equivalence ratio (liquid length)
                       % set to zero to use Siebers' method to determine equivalence ratio
							  % at the liquid length

dtplot = 20e-6; 	     % time interval between plots
diplot = 0; 			  % iteration interval between plots
fontsize=14;           % fontsize in plots
linewidth = 2;         % line width in plots
make_movie = 1;        % 0 - no & 1 - yes
moviefile = 'SteadyStateVP';
Contours = '[0.2:0.2:1.0 2:2:10]';     % equivalence ratio contours
colors = {[.2 .8 0];[.4 .6 0];[.6 .4 0];[.8 .2 0];'r';...
         [.6 0 0];[.4 0 0];[.2 0 0];[.1 0 0];'k'}; % colors for contour plots

% overwrite default values with those in Run_Parameters
for i=1:size(Run_Parameters)
   eval(Run_Parameters{i});
end
%------------------ End User Input Variables -----------------------------------------


%---------------------- Initializations -----------------------------------------------
clear Md mdf AreaContract ujet;
D_f = Diameter*sqrt(Ca);               % Adjusted nozzle diameter
A0 = pi*D_f^2/4;                       % [m^2] adjusted injector cross sectional area
if velocity_profile == 0 & adjust_theta == 1 
   theta=2*atand(tand(theta/2)*a_Siebers); % [degrees] Siebers angle for uniform velocity calc.
end
x0=D_f/2/tand(theta/2);                % [m] theoretical jet point origin

eval(sprintf('Contour_levels = %s;',Contours));   %Set contour levels
stoich = stoich_air*(28.97*(1-fN2)+28*fN2)/(28.97*(1-fN2)); % adjust stoichiometery for N2 fraction (simulated EGR)

% set phi threshold for liquid length based on Siebers' method, using look-up table
if (phi_threshold == 0)        % calculate the phi threshold to give n-C17 liquid length
   FA = LLFA(T_a,rho_a,'c17');       % F/A ratio at liquid length for given conditions
   phi_threshold = stoich*FA;  % equivalence ratio at liquid length
   if velocity_profile==0
      phi_threshold = phi_threshold*.25/.41; % adjustment for "b" in 1999-01-0528
   end
end
disp(phi_threshold)
disp(rho_a)

% Set up domain
% x represents the coordinates of the control volume boundaries, so x is one element greater
% than the total number of control volumes
x = [dx/2:dx:total_length];        % coordinates of CV centers, relative to nozzle exit 
A = pi*(tand(theta/2)*(x+x0)).^2;  % area at CV centers
V = A*dx;                          % CV Volumes (treat as cylinders)

% calculate alpha, beta, and gamma of the velocity distribution
alpha = ones(size(A))*1.5;   % Initialize alpha with fully-developed profile
i=1;
while(i)                     % previous alpha not yet steady
   r = rho_f/rho_a;          % density ratio
   P = [6*(A(i)/A0-1) -(7+18*r) -(2+33*r) -20*r -4*r]; % 4th order polynomial coefficients
   alpha(i) = max(roots(P));    % largest polynomial root is alpha
   if alpha(i)<1.5
      alpha(i) = 1.5;           % fully developed jet reached, so end loop
      i=0;
   else
      i=i+1;                    % fully developed jet not yet reached, so continue loop
   end
end

beta = 6*(alpha+1).*(alpha+2)./(3*alpha+2)./(2*alpha+1); % integrated velocity profile factor
gamma = (alpha+1).*(alpha+2)./alpha.^2; % for converting from centerline to average velocity
if velocity_profile==0  % if uniform velocity profile is used
   beta = ones(size(beta));
   gamma = ones(size(gamma));
   alpha = ones(size(alpha))*1e99;
end

% Calculate steady jet quantities
mdotf0 = rho_f*A0*max(InjParams(1,:));  % fuel mass flux at nozzle, max in injection rate profile chosen as "steady"
Mdot0 = rho_f*A0*max(InjParams(1,:))^2; % Momentum flux at nozzle, max in injection rate profile chosen as "steady"
Ubarsteady = ((rho_a-rho_f)/rho_f*mdotf0+sqrt(((rho_f-rho_a)/rho_f*mdotf0)^2 ...
   +4*beta*rho_a.*A*Mdot0))/2./beta/rho_a./A; % Averaged velocity
Xfsteady = mdotf0./beta/rho_f./Ubarsteady./A; % fuel volume fraction in center of CVs
mfsteady = rho_f*Xfsteady.*A*dx;                % fuel mass flux for steady jet
dbetadx = (beta-[1 beta(1:end-1)])/dx;          % beta gradient
EntRatesteady = rho_a*Mdot0*(2*A./(x+x0)+A.*dbetadx./beta)...
   ./sqrt(((rho_f-rho_a)/rho_f*mdotf0)^2+4*beta*rho_a.*A*Mdot0) ...
   +1/2*((rho_a-rho_f)/rho_f*mdotf0+sqrt(((rho_f-rho_a)/rho_f*mdotf0)^2 ...
   +4*beta*rho_a.*A*Mdot0))*(-1)./beta.^2.*dbetadx; % Entrainment rate
RelEntRatesteady = EntRatesteady*dx./mfsteady;            % relative entrainment rate
phisteady = rho_f*Xfsteady./(rho_a.*(1-Xfsteady))*stoich; % steady jet equivalence ratio
FAsteady = rho_f*Xfsteady./(rho_a.*(1-Xfsteady)); 
% calculate steady-jet penetration
M = cumtrapz([0 x],[0 (rho_a+(rho_f-rho_a)*Xfsteady).*A.*Ubarsteady]); % integrated momentum
t_steady = M/Mdot0;  % time to deliver integrated momentum at maximum nozzle Mdot rate

t = 0;                              % [s] run time in while loop
mf = zeros(size(x));                % Initial CV fuel mass
M =zeros(size(x));                  % Initial CV momentum
m = V*rho_a;                        % Initial CV mass (filled with ambient gas)
Ubar = zeros(size(x));              % Initial CV velocity
Xf = zeros(size(x));                % Initial fuel mass fraction
rho = rho_a*ones(size(x));          % Initial density
Unoz = InjVel(InjType,InjParams,0); % velocity at nozzle
i = 1;                              % i = 1 refers to time = 0*dt
Penetration1=0;                     % [m] based on momentum flux (jet head)
Penetration2=0;                     % [m] based on equivalence ratio (liquid length)
imovie = 0;                         % used in movie loop
%-------------------------- End Initializations -------------------------------------------



%------------------------ Start of Main Iteration -----------------------------------------
while t(end) < Run_Time
   %if restart
   %   load(restartfile);
   %   restart=0;
   %end
   
   % calculate mass and momentum fluxes

   mdotf0 = A0*rho_f*Unoz;           % fuel mass flux at nozzle
   Mdot0  = A0*rho_f*Unoz^2;			 % momentum flux at nozzle
   % special calculation for U = Usteady at EOI LMP
   % mdotf0 = A0*rho_f*Unoz^2/Usteady^2*Usteady;
   CA2 = Ca;
   %if t(end) > 0.5e-3
   if 0
      Usteady = 418.9539; %steady value, temporary
      CA2 = Ca*Unoz^2/Usteady^2; %change to area contraction
      mdotf0 = A0*rho_f*Unoz^2/Usteady;
   end
   AreaContract(i) = CA2;
   Md(i) = Mdot0;
   mdf(i) = mdotf0;
   ujet(i) = Unoz;
   
   mdotf = beta.*A*rho_f.*Xf.*Ubar;  % fuel mass flux in jet
   Mdot = beta.*A.*rho.*Ubar.^2;     % momentum flux in jet
   
   %Calculate time step based on Courant number and U values
   dt=dtmax; % limit time step size for situations where Ubar is low (like start of ramping injection)
   Umax = max([Unoz Ubar 1]);
   dt = min([dt dx/Umax*Courant]);

   % Calculate new fuel mass and momentum in CVs
   
   mf = mf + ([mdotf0 mdotf(1:end-1)] - mdotf)*dt;
   M  = M  + ([ Mdot0  Mdot(1:end-1)] -  Mdot)*dt;
   
   t=[t t(end)+dt];   % update time
   i=i+1;             % update iteration count
   

   % Take care of situation where volume of fuel exceeds volume of CV 
   % (can occur near injector for some ramped injections)
   % Put extra fuel mass and momentum into next CV downstream
   Vf = mf/rho_f;           % volume of fuel in each CV
	ii = find(Vf>V);
	while ~isempty(ii)
      jj=ii(1);
		mass_swap =  rho_f * (Vf(jj)-V(jj))*1.001; % 1.001 keeps phi < infinity
		mf(jj+1) = mf(jj+1) + mass_swap;
		M(jj+1) = M(jj+1) + mass_swap/mf(jj) * M(jj);
		M(jj) = M(jj) - mass_swap/mf(jj) * M(jj);
      mf(jj) = mf(jj) - mass_swap;
      Vf = mf/rho_f;
		ii = find(Vf>V);
   end
   
   % Calculate new CV fuel and ambient gas quantities
   Xf = Vf./V;              % volume fraction of fuel
	Va = V-Vf;	             % volume of ambient gas in each CV
	ma = Va*rho_a;           % mass of ambient gas in each CV
   m  = mf+ma;              % total mass in CV
   rho = m./V;              % CV densities
   FA_Ratio =[mf./ma];      % fuel-to-ambient ratio
   phi = FA_Ratio.*stoich;  % equivalence ratio

	% Calculate average velocities from CV mass and momentum
	Ubar = M./m;                                 % mean velocity in jet
   Unoz = InjVel(InjType,InjParams,t(end));     % velocity at nozzle

   % Calculate the entrainment rate
   Vdot0 = A0*Unoz;                         % volume flux at nozzle
   Vdot = A.*Ubar;                          % volume flux in jet
   dVdot = Vdot-[Vdot0 Vdot(1:end-1)];      % differential volume flux
   EntRate = dVdot*rho_a/dx;                % [kg/s/m] mass entrainment flux of ambient gas 
   ii = find(mf>0);        					  % prevent divide by zero error
   RelEntRate = zeros(size(EntRate));       % initialize
   RelEntRate(ii) = EntRate(ii)./mf(ii)*dx; % [1/s] relative entrainment rate
   
   % First type of penetration calculation: threshold is M_threshold of maximum  
   % Momentum flux, which is approximately constant with x for steady jets, so it 
   % works well for penetration of the whole jet
   ii = find(Mdot>M_threshold*max([Mdot0 Mdot]));
   if isempty(ii), Penetration1(i) = 0; 
	else Penetration1(i) = x(ii(end)); end
   
   % Second type of penetration calculation: 
   % Calculate penetration using absolute equivalence ratio (e.g., for liquid length)
   ii = find(phi.*gamma > phi_threshold); 
   if isempty(ii), Penetration2(i)=0;
   else Penetration2(i)=x(ii(end)); end
   %------------ End of Calculations Section of Main Iteration ---------------------
   
   
   %------------------------ Plotting in Main Iteration ---------------------------
   doplot = diplot & (i == 2 | mod(i,diplot) == 0);
   if dtplot>0 % if statement is to prevent divide by zero error
      doplot = doplot | floor(t(end)/dtplot)>floor(t(end-1)/dtplot);
   end
   
	if doplot
		figno=20;
		figure(figno);close(figno);figure(figno);
      set(gcf,'Position',[100 50 900 600],'Color',[1 1 1]);
      
      axpos4 = [.08 .09 .31 .3];
		axpos3 = [.08 .5 .37 .4];
		axpos2 = [.57 .5 .38 .4];
      axpos1 = [.57 .09 .38 .29];
      
      % Set up transition points in the rate of injection function that 
      % are plotted as the penetrate with the jet
      ii = find(InjParams(2,:)<t(end)); % indeces of transition points so far in injection
      t_trans = t(end);                 
      if ~isempty(ii), t_trans = [t_trans t(end)-InjParams(2,ii)]; end % relative time
      x_trans = interp1(t_steady,[0 x],t_trans); % penetration at transition times
      x_trans_plot = [1;1;NaN]*x_trans*1000;       % set up array for plotting
      
      % ------------------- Contour Plot -----------------------------------------
      ax1 = axes('Position',axpos1);
      Contour_Plotter(figno,phi,x,(x+x0)*tand(theta/2),linewidth,fontsize,...
         [Contour_levels phi_threshold],{colors{:} 'b'},alpha);
     %disp(phi_threshold)
      axis equal;
      xlim1 = [0 90];
      ylim1 = [-15 15];
      set(gca,'XLim',xlim1,'YLim',ylim1);
      xlabel('Axial Distance [mm]','FontSize',fontsize);
      %ylabel('Radial Distance [mm]','FontSize',fontsize);
      ht= text(xlim1(1)+0.05*diff(xlim1),ylim1(2)-0.05*diff(ylim1),'Equivalence Ratio Contours');
      set(ht,'FontSize',fontsize,'VerticalAlignment','top');
      set(gca,'FontSize', fontsize,'LineWidth',linewidth,'YTickLabel',[],'XTick',0:10:90,'Ytick',-10:5:10);
      
      axpos1b = [axpos1(1)-.05 axpos1(2) .03 axpos1(4)];
      ax1b = axes('Position',axpos1b);
      for j=1:length(Contour_levels)
         hf = fill([0 1 1 0 0],[j-1 j-1 j j j-1],colors{j});
         set(hf,'EdgeColor','none');
         hold on;
      end
      set(gca,'YTick',(1:length(Contour_levels))-.5,'YTickLabel',Contour_levels,'XTick',[],...
         'YLim',[0 length(Contour_levels)]);
      set(gca,'FontSize', fontsize);
		
% ---------------------- Mean Equivalence Ratio Plot ------------------------------------
		if(1)
		ax2 = axes('Position',axpos2);
      
      Eratio = EntRate./EntRatesteady;
      REratio = RelEntRate./RelEntRatesteady;
      h1=plot(x*1000,Eratio,'b','LineWidth',linewidth);
      set(ax2,'YGrid','on');
      hold on;
      h2 = plot(x*1000,REratio,'--b','LineWidth',linewidth);
      hl = legend([h1 h2],'Relative Entrainment Rate','Rel. Entrain. Rate / Fuel');
      lpos= get(hl,'Position');
      set(hl,'Position',[.58 .92 lpos(3:4)]);
		set(gca,'FontSize', fontsize,'LineWidth',linewidth);
      legend(hl); % this blitzes the legend handle.
      hl = legend(gca); 

		box off;
      hold on;
      

      %ylabel('Relative Entrainment Rate','Fontsize',fontsize);
		%axis([0, total_length*1000, log10(.1),log10(10)]);
      %xlim1 = xlim;
      %ylim1 = ylim;
      hold on;
      %plot((ones(17,1)*[xlim1 NaN])',(log10([.2:.1:1 2:9])'*[1 1 NaN])',':','Linewidth',1,'Color',[.5 .5 .5]);

      %ht = text(xlim1(2)-0.015*diff(xlim1),10^mean(log10(ylim1)),'Relative Entrain. Rate');
      %set(ht,'Fontsize',fontsize,'VerticalAlignment','bottom','HorizontalAlignment','center','Rotation',90);
      set(gca,'YAxisLocation','right','XAxisLocation','top','XTickLabel',[]);
      %set(gca,'YTick',log10([.1:.1:1 2:10]),'YTickLabel',{'0.1';'0.2';'0.3';'';'0.5';'';'';...
      %      '';'';'1.0';'2.0';'3.0';'';'5.0';'';'';'';'';'10'});
      set(gca,'FontSize', fontsize,'LineWidth',linewidth);
      set(gca,'YTick',[0:0.5:4]);
      ylim([0 4]);
      
		ax2b = axes('Position',axpos2);

      ytick = [0 .1 .3 1 2 5 10 20 50 100 200];
      % adding 1 to log calculation allows plotting to zero on a pseudo-log scale
      plot(x*1000,log(phisteady+ytick(2)),'-','LineWidth',linewidth,'Color',[.5 .5 .5]);
      hold on
      
		y_trans_plot = log([ytick(1);ytick(end);NaN]*ones(size(x_trans))+ytick(2));
      h = plot(x_trans_plot,y_trans_plot,'-','LineWidth',1);
      set(h,'Color',[.5 .5 .5]);
      
		plot(x*1000, log(phi+ytick(2)),'r','LineWidth',linewidth);
		ylabel ('Mean Equivalence Ratio [-]','FontSize',fontsize);
		xlabel ('Axial Distance [mm]','FontSize',fontsize);
      axis([0, total_length*1000, log(ytick([1 end])+ytick(2))]);
      set(gca,'YTick',log(ytick+ytick(2)),'YTickLabel',ytick,'XTick',0:20:100);

      set(gca,'Color','none','FontSize', fontsize,'LineWidth',linewidth);
      box off;
      hold on;
		end
% --------------------- Mean Velocity Plot -------------------------------------
		
		ax3 = axes('Position',axpos3);
		ymax = ceil(max(InjParams(1,:))/100)*100;
      ytick = [0 1 3 10 20 50 100 ymax];
      h1 = plot(x*1000,log(Ubarsteady+1),'-','LineWidth',linewidth,'Color',[.5 .5 .5]);
      hold on
      
		y_trans_plot = log([ytick(1);ytick(end);NaN]*ones(size(x_trans))+1);
      h = plot(x_trans_plot,y_trans_plot,'-','LineWidth',1);
      set(h,'Color',[.5 .5 .5]);

		h2 = plot(x*1000, log(Ubar+1),'r','LineWidth',linewidth);
      
		hl2 = legend([h1 h2],'Steady-State Analytic', 'Control Volume Model');
      %set(hl2,'FontSize',1);

		%plot(x(3:end)*1000, U(3:end),'r','LineWidth',linewidth);
		titlestr = sprintf('Time = %2.3f ms at iteration %d' ,t(end)*1000,i);
      title(titlestr,'FontSize',fontsize);
		xlabel ('Axial Distance [mm]','FontSize',fontsize)
		ylabel ('Mean Velocity [m/s]','FontSize',fontsize)
      
      %legend(hl2); % very stupid way to set legend font size.
      %hl2 = legend(gca); % restore legend handle
		set(gca,'FontSize',fontsize,'LineWidth',linewidth)
		axis([0, total_length*1000, log(ytick([1 end])+ytick(2))]);
%      set(gca,'YTick',log(ytick+1),'YTickLabel',ytick,'XTick',0:20:100);
      
% --------------------- Penetration Plot ----------------------------
		if(1)
      ax4 = axes('Position',axpos4,'YAxisLocation','right','XAxisLocation','top',...
         'XTick',[0:0.5:10],'XTickLabel',[]);
      hold on;
      % Plot injection rate shape
      tinjplot = [0:1e-5:Run_Time];
      h1 = plot(tinjplot*1000,InjVel(InjType,InjParams,tinjplot),'-k','LineWidth',linewidth);
      ylim([0 round(max(InjParams(1,:)/100)+1)*100]);
      hold on;
      set(h1,'Color',[.4 .4 .4]);

      tinjplot = [0:1e-5:t(end)];
      plot(tinjplot*1000,InjVel(InjType,InjParams,tinjplot),'-r','LineWidth',linewidth);
      h2 = plot([t(end) t(end)]*1000,ylim,'-','LineWidth',1);
      set(h2,'Color',[.6 .6 .6]);
      ylabel('Injection Velocity [m/s]','Fontsize',fontsize);
      axis([0 ceil(Run_Time*1000) 0 round(max(InjParams(1,:)/100)+1)*100]);
      set(gca,'FontSize', fontsize,'LineWidth',linewidth);
      hold on;
      box off;
      
		ax4b = axes('Position',axpos4,'Color','none');
		hold on;

        %plot(t_Siebers*1000,S_Siebers*1000, '-','LineWidth',linewidth,'Color',[.8 .5 .5]);
      plot(t_steady*1000,[0 x]*1000, '-','LineWidth',linewidth,'Color',[.5 .5 .5]);
      hold on;
      plot(t*1000, Penetration1*1000,'r','LineWidth',linewidth);
      plot(t*1000, Penetration2*1000,'b','LineWidth',linewidth);
 		xlabel ('Time [ms]','FontSize',fontsize);
 		ylabel ('Penetration [mm]','FontSize',fontsize);
      set(gca,'FontSize', fontsize,'LineWidth',linewidth);
      axis([0 ceil(Run_Time*1000) 0 total_length*1000]);
      set(gca,'YTick',0:20:100,'XTick',0:0.5:10);
      if (Run_Time>5e-3), set(gca,'XTick',0:1:10); end
      %ht = text(1.1,50,{['Amb. Dens. = ' num2str(rho_a,'%3.1f')]; ['Amb. Temp. = ' num2str(T_a,'%4.0f')];});
      %set(ht,'FontSize',fontsize,'VerticalAlignment','top');
      
      %box on;
      box off;
   	end
   
      pause(.1);
      legend;
		pause(.1);

        if make_movie == 1
            imovie=imovie+1;
            fname = sprintf('%s%03d',moviefile,imovie);
            %save a few select variables to dout
            dout.x{imovie} = x;
            dout.radius{imovie} = (x+x0)*tand(theta/2);
            dout.alpha{imovie} = alpha;
            dout.FA{imovie} = FA_Ratio;
            dout.Xf{imovie} = Xf;
            dout.t(imovie) = t(end)*1000;
            dout.Eratio{imovie} = Eratio;
            %dout.U(imovie)= Uhead;
            dout.S(imovie)= Penetration1(end);
            %print(gcf,'-djpeg',fname);
            
        end
	end
end
t(end) = [];
%write out centerline data to predict liquid length
    Xfsteadycl = Xfsteady.*gamma.*(1-0.^alpha).^2;
    FAsteadycl = rho_f*Xfsteadycl./(rho_a.*(1-Xfsteadycl)); 
    Lind = find(FAsteadycl<BT);
    LiqLen = x(Lind(1));
    R = (x+x0)*tand(theta/2);
save([moviefile 'out.mat'], 'dout', 'Xfsteady','FAsteady','t_steady', 'Ubarsteady','mdotf0',...
    'theta','x0','rho_a','rho_f','D_f','alpha','x','R','FAsteadycl','LiqLen','gamma')
%save([moviefile '.mat'], 't','Md','mdf','AreaContract','ujet')
%----------------------- End of Main Iteration ---------------------------
toc
