function [time,x,FA] = Siebers_Penetration( rho_fuel , rho_air , m , alpha , x , x_sub0 , U0, d_subf )
% Returns relationship between penetration and time using Naber and Siebers
% equations.
%   Inputs are (1) Density of fuel
%              (2) Density of charge
%              (3)  m - equation variable that either neglects the area of
%                      fuel(set to 0) or includes the area of fuel(set to 1)
%              (4) The angle of the full spray used in the model.  This is
%                  related to the measured spray angle by tan(alpha/2) = a * tan(theta/2) 
%                  where theta is the angle measured by experiment.  
%              (5) The axial distance where time to penetration is desired.
%              (6) The axial distance from edge of injector to theoretical
%                  location of point injection.
%              (7) The injector velocity.
%              (8) The effective orifice diameter in meters of the
%                  injector.

%   Output: Matrix containing distance and matrix containing
%           corresponding penetration time


rho_tilda = rho_fuel / rho_air; 
x_suba = m/2 * d_subf/tand(alpha/2);
x_prime = x + x_sub0;
x_plus = d_subf * rho_tilda^0.5 * ((rho_tilda - m)/rho_tilda) * 1/tand(alpha/2);
t_plus = d_subf * rho_tilda^0.5 * ((rho_tilda-m)/rho_tilda)^2 * 1/(U0*tand(alpha/2));
S_tilda = x_prime ./ x_plus;         
         
t_tilda = S_tilda./2 + S_tilda./4 .* sqrt(1 + 16 .* S_tilda.^2) + 1/16 .* log(4 .* S_tilda + sqrt(1 + 16 .* S_tilda.^2));

t_sub0 = t_tilda(1,1) * t_plus;
t_prime = t_tilda .* t_plus;
time = t_prime - t_sub0 ;
FA = 2./( sqrt(1 + 16* S_tilda.^2) -1 );